==> deepin-fcitx5configtool-plugin_6.0.12.tar.xz: BUILD/src-old/src/dcc-module/translations/deepin-fcitx5configtool-plugin_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>AddIMPage</name>
    <message>
        <source>Select your language and add input methods</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Find more in App Store</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Fcitx5ConfigPlugin</name>
    <message>
        <source>deepin-fcitx5configtool-plugin</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Input Method</source>
        <translation>Méthode de saisie</translation>
    </message>
</context>
<context>
    <name>IMSettingWindow</name>
    <message>
        <source>Manage Input Methods</source>
        <translation>Gérer les méthodes de saisie</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Raccourcis</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Réinitialiser</translation>
    </message>
    <message>
        <source>Scroll between input methods</source>
        <translation>Faire défiler les méthodes de saisie</translation>
    </message>
    <message>
        <source>Switch between the current/first input method</source>
        <translation>Basculer entre la méthode de saisie actuelle/première</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>Paramètres avancés</translation>
    </message>
</context>
<context>
    <name>LayoutWidget</name>
    <message>
        <source>The current input method has no keyboard layout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Multiple input methods have been selected</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dcc_fcitx_configtool::widgets::FcitxKeyLabelWidget</name>
    <message>
        <source>Enter a new shortcut</source>
        <translation>Entrez un nouveau raccourci</translation>
    </message>
</context>
</TS>

==> deepin-fcitx5configtool-plugin_6.0.19.tar.xz: BUILD/src-old/src/dcc-module/translations/deepin-fcitx5configtool-plugin_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>AddIMPage</name>
    <message>
        <source>Select your language and add input methods</source>
        <translation>Sélectionnez votre langue et ajoutez des méthodes de saisie</translation>
    </message>
    <message>
        <source>Find more in App Store</source>
        <translation>Trouvez plus dans l'App Store</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
</context>
<context>
    <name>Fcitx5ConfigPlugin</name>
    <message>
        <source>deepin-fcitx5configtool-plugin</source>
        <translation>deepin-fcitx5configtool-plugin</translation>
    </message>
    <message>
        <source>Input Method</source>
        <translation>Méthode de saisie</translation>
    </message>
</context>
<context>
    <name>IMSettingWindow</name>
    <message>
        <source>Manage Input Methods</source>
        <translation>Gérer les méthodes de saisie</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Raccourcis</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Réinitialiser</translation>
    </message>
    <message>
        <source>Scroll between input methods</source>
        <translation>Faire défiler les méthodes de saisie</translation>
    </message>
    <message>
        <source>Switch between the current/first input method</source>
        <translation>Basculer entre la méthode de saisie actuelle/première</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>Paramètres avancés</translation>
    </message>
</context>
<context>
    <name>LayoutWidget</name>
    <message>
        <source>The current input method has no keyboard layout</source>
        <translation>La méthode de saisie actuelle n'a pas de disposition de clavier</translation>
    </message>
    <message>
        <source>Multiple input methods have been selected</source>
        <translation>Plusieurs méthodes de saisie ont été sélectionnées</translation>
    </message>
</context>
<context>
    <name>dcc_fcitx_configtool::widgets::FcitxKeyLabelWidget</name>
    <message>
        <source>Enter a new shortcut</source>
        <translation>Entrez un nouveau raccourci</translation>
    </message>
</context>
</TS>
